#!/bin/bash

set -eux

script_dir="$(dirname "$(readlink -f "$0")")"
source ${script_dir}/utils.sh

###
# Read config
###

echo "Reading deployment app config"
read_config "." "./config/deployment-config.yaml"

echo "Reading deployment base config"
read_config "." "./config/sade-cd-common-config.yaml"

echo "Printing updated environment"
printenv

###
# gcloud setup
###

gcloud config set project ${project_id}
workload_prefix="${workload_name}/${workload_name}-${workload_version}"

###
# Upload Spark artifacts
###

echo "Uploading Spark artifacts"
gcloud storage rsync \
    ${spark_folder} \
    gs://${tools_bucket}/${workload_prefix} \
    --recursive \
    --delete-unmatched-destination-objects

echo "Preparing to cleanup old versions in SADE tools bucket"
delete_old_versions ${tools_bucket}

###
# Upload DAGs artifacts
###

echo "Creating DAG config"
dag_config="${dags_folder}/config.yaml"
echo "---" > ${dag_config}
echo "# Common setup, shared for all job in this env" >> ${dag_config}
echo "environment:" >> ${dag_config}
sed -e 's/^/  /' ./config/sade-cd-common-config.yaml >> ${dag_config}
echo "" >> ${dag_config}
cat "./config/dags-config.yaml" >> ${dag_config}

echo "Uploading DAGs artifacts"
dags_root="${dags_bucket}/dags/${dags_prefix}"
gcloud storage rsync \
    ${dags_folder} \
    gs://${dags_root}/${workload_prefix} \
    --recursive \
    --delete-unmatched-destination-objects

echo "Preparing to cleanup old DAGs"
delete_old_versions ${dags_root}
